@@ -2,7 +2,7 @@ from hachoir_regex.regex import (RegexEmpty,
     RegexString, createString,
     RegexRangeItem, RegexRangeCharacter, RegexRange, createRange,
     RegexAnd, RegexOr, RegexRepeat,
-    RegexDot, RegexStart, RegexEnd)
+    RegexDot, RegexStart, RegexEnd, RegexWord)
 from hachoir_regex.parser import parse
 from hachoir_regex.pattern import PatternMatching
 
